==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_functions/mp3018_001/MP3018_SyncDepreciation_001.java <==

package net.datastream.schemas.mp_functions.mp3018_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.depreciation_001.Depreciation;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/Depreciation_001}Depreciation"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Depreciation" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "depreciation"
})
@XmlRootElement(name = "MP3018_SyncDepreciation_001")
public class MP3018_SyncDepreciation_001 {

    @XmlElement(name = "Depreciation", namespace = "http://schemas.datastream.net/MP_entities/Depreciation_001", required = true)
    protected Depreciation depreciation;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété depreciation.
     * 
     * @return
     *     possible object is
     *     {@link Depreciation }
     *     
     */
    public Depreciation getDepreciation() {
        return depreciation;
    }

    /**
     * Définit la valeur de la propriété depreciation.
     * 
     * @param value
     *     allowed object is
     *     {@link Depreciation }
     *     
     */
    public void setDepreciation(Depreciation value) {
        this.depreciation = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.DEPRECIATION;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_functions/mp3018_001/MP3018_SyncDepreciation_001.java <==

package net.datastream.schemas.mp_functions.mp3018_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.depreciation_001.Depreciation;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/Depreciation_001}Depreciation"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Depreciation" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "depreciation"
})
@XmlRootElement(name = "MP3018_SyncDepreciation_001")
public class MP3018_SyncDepreciation_001 {

    @XmlElement(name = "Depreciation", namespace = "http://schemas.datastream.net/MP_entities/Depreciation_001", required = true)
    protected Depreciation depreciation;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the depreciation property.
     * 
     * @return
     *     possible object is
     *     {@link Depreciation }
     *     
     */
    public Depreciation getDepreciation() {
        return depreciation;
    }

    /**
     * Sets the value of the depreciation property.
     * 
     * @param value
     *     allowed object is
     *     {@link Depreciation }
     *     
     */
    public void setDepreciation(Depreciation value) {
        this.depreciation = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.DEPRECIATION;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
